==> vandal-3.8.9.tar.gz: vandal-3.8.9/README.md <==
![vandal-header](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandal.jpg)

[![Downloads](https://img.shields.io/pypi/dm/vandal?color=F43&label=Downloads&style=flat-square)](https://pypi.org/project/vandal)
[![License](https://img.shields.io/pypi/l/vandal?color=178&label=License&style=flat-square)](https://github.com/dkundih/vandal/blob/main/LICENSE)
[![PyPi version](https://img.shields.io/pypi/v/vandal?color=178&&label=PyPi%20version&style=flat-square)](https://pypi.org/project/vandal)
[![Python version](https://img.shields.io/pypi/pyversions/vandal?color=178&label=Python%20version&style=flat-square)](https://pypi.org/project/vandal)
[![Latest publish](https://img.shields.io/github/last-commit/dkundih/vandal?color=178&label=Latest%20publish&style=flat-square)](https://github.com/dkundih/vandal)
[![Format](https://img.shields.io/pypi/format/vandal?color=178&label=Format&style=flat-square)](https://pypi.org/project/vandal)

vandal
=====

Data science, Data manipulation and Machine learning library.
Use permitted according to the terms of use and conditions set by the attached license.

**Example of use**

Visit my Data Library at https://github.com/dkundih/DataLibrary in order to see the demonstration of use in practical examples.

**Installation**

```sh
# using pip.
pip install vandal
```

**Dependencies**

```sh
# using pip.
pip install vandal -r requirements.txt
```


<h3>Terminal CLI application</h3>

vandal provides an option of being run within any terminal as a data science/machine learning application. 

**Terminal options**

```sh
# terminal app options help.
python -m vandal -h / python -m vandal --help
```

```sh
# terminal app entry choices.
python -m vandal -e / python -m vandal --entry
```

```sh
# terminal app entry example.
python -m vandal -e montecarlo / python -m vandal --entry montecarlo
```

**Example use**

<b>TERMINAL USE #1</b>
![vandal-terminal1](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI1.jpg)
<b>TERMINAL USE #2</b>
![vandal-terminal2](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI2.jpg)
<b>EXAMPLE GRAPH</b>
![vandal-terminal3](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI3.jpeg)
<b>EXAMPLE OUTPUT</b>
![vandal-terminal4](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI4.jpg)


<h3>Python library</h3>

vandal functions as a library that can be run in python/jupyter environment and also integrated in other libraries and projects.

**Import**

```sh
# import the library.
import vandal
```

**Help**

```sh
# library help.
print(help(vandal))
```

```sh
# module/object help.
print(help(vandal.MonteCarlo))
```

**Meta data**

```sh
# meta data (individual).
print(vandal.__version__)
```

```sh
# all meta data.
print(help(vandal.misc._meta))
```

**Library location**

```sh
# file location after installation.
print(help(vandal.__file__))
```

**For whom is vandal made for?**

vandal is a Python library for Data science and Machine learning, designed to aid researchers and engineers to meet their goals with small effort.

**Why vandal?**

As a vandal gives abandoned walls meaning with graffiti, so does vandal library to the data.

**Is vandal free to use?**

vandal is completely free of charge for both personal and commercial use, but only under the conditions stated in the license. Developing such a complex library isn't easy and takes a lot of time and knowledge in several fields of science such as statistics, programming and domain knowledge, so any donation at https://patreon.com/dkundih or https://www.buymeacoffee.com/dkundih in order to keep vandal free is more than welcome.

**A word from the author!**

The library itself, it's maintenance, updates and stability, logo, videos, promotional materials and everything associated with duality are done by **David Kundih** from **Croatia**.

<h1 align='center'> Hi! :wave:</h1>
 
<img src='https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/BLUERED_GHiLI.jpg'/>

<p align='center'>
My name is <b>David Kundih</b> and I am a Master's student of <b>Sustainable mobility and logistics</b> at the <b>University North</b>, currently specializing in <b>Digital transformation of traffic and logistics using Python.</b>
</p>
 
<h4 align='center'>My latest projects:</h4>
<p align='center'>
<a href="https://github.com/dkundih/vandal">vandal</p>  
<p align='center'>
<a href="https://github.com/dkundih/duality">duality</p>  
<p align='center'>
<a href="https://github.com/dkundih/logistics">logistics</p>  
<p align='center'>
<a href="https://github.com/dkundih/unin">unin</a></p>
</p>

<h3 align='center'><i>People shine the brightest when they seek to understand what kind of love sustains them.</i></h3>

<p align='center'>
<a href="https://www.instagram.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/instagram.jpg"></a>
<a href="https://www.facebook.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/fb.jpg"></a>
<a href="https://www.linkedin.com/in/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/linkedin.png"></a>
<a href="https://www.pypi.org/user/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/pypi.jpg"></a>
<a href="https://www.buymeacoffee.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/buymeacoffee.jpg"></a>
<a href="https://www.patreon.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/patreon.jpg"></a>
<a href="https://www.behance.net/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/behance.jpg"></a>
<a href="https://www.researchgate.net/profile/David-Kundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/rg.jpg"></a>

==> vandal-4.0.8.tar.gz: vandal-4.0.8/README.md <==
![vandal-header](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandal.jpg)

[![Downloads](https://img.shields.io/pypi/dm/vandal?color=F43&label=Downloads&style=flat-square)](https://pypi.org/project/vandal)
[![License](https://img.shields.io/pypi/l/vandal?color=178&label=License&style=flat-square)](https://github.com/dkundih/vandal/blob/main/LICENSE)
[![PyPi version](https://img.shields.io/pypi/v/vandal?color=178&&label=PyPi%20version&style=flat-square)](https://pypi.org/project/vandal)
[![Python version](https://img.shields.io/pypi/pyversions/vandal?color=178&label=Python%20version&style=flat-square)](https://pypi.org/project/vandal)
[![Latest publish](https://img.shields.io/github/last-commit/dkundih/vandal?color=178&label=Latest%20publish&style=flat-square)](https://github.com/dkundih/vandal)
[![Format](https://img.shields.io/pypi/format/vandal?color=178&label=Format&style=flat-square)](https://pypi.org/project/vandal)

vandal
=====

Data science, Data manipulation and Machine learning library.
Use permitted according to the terms of use and conditions set by the attached license.

**Example of use**

Visit my Data Library at https://github.com/dkundih/DataLibrary in order to see the demonstration of use in practical examples.

**Installation**

```sh
# using pip.
pip install vandal
```

**Dependencies**

```sh
# using pip.
pip install vandal -r requirements.txt
```

<h3>GUI applications</h3>

vandal provides an option of being run within any terminal as a data science/machine learning application in the form of a GUI. 

```sh
# terminal app entry choices for GUI apps.
python -m vandal -e montecarlogui / python -m vandal --entry montecarlogui
```

<h3>Terminal CLI application</h3>

vandal provides an option of being run within any terminal as a data science/machine learning application. 

**Terminal options**

```sh
# terminal app options help.
python -m vandal -h / python -m vandal --help
```

```sh
# terminal app entry choices.
python -m vandal -e / python -m vandal --entry
```

```sh
# terminal app entry example.
python -m vandal -e montecarlo / python -m vandal --entry montecarlo
```
**Example use**

<b>TERMINAL USE #1</b>
![vandal-terminalgui](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/MCGUI.png)

**Example use**

<b>TERMINAL USE #1</b>
![vandal-terminal1](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI1.jpg)
<b>TERMINAL USE #2</b>
![vandal-terminal2](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI2.jpg)
<b>EXAMPLE GRAPH</b>
![vandal-terminal3](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI3.jpeg)
<b>EXAMPLE OUTPUT</b>
![vandal-terminal4](https://raw.githubusercontent.com/dkundih/vandal/master/_logistics/vandalCLI4.jpg)


<h3>Python library</h3>

vandal functions as a library that can be run in python/jupyter environment and also integrated in other libraries and projects.

**Import**

```sh
# import the library.
import vandal
```

**Help**

```sh
# library help.
print(help(vandal))
```

```sh
# module/object help.
print(help(vandal.MonteCarlo))
```

**Meta data**

```sh
# meta data (individual).
print(vandal.__version__)
```

```sh
# all meta data.
print(help(vandal.misc._meta))
```

**Library location**

```sh
# file location after installation.
print(help(vandal.__file__))
```

**For whom is vandal made for?**

vandal is a Python library for Data science and Machine learning, designed to aid researchers and engineers to meet their goals with small effort.

**Why vandal?**

As a vandal gives abandoned walls meaning with graffiti, so does vandal library to the data.

**Is vandal free to use?**

vandal is completely free of charge for both personal and commercial use, but only under the conditions stated in the license. Developing such a complex library isn't easy and takes a lot of time and knowledge in several fields of science such as statistics, programming and domain knowledge, so any donation at https://patreon.com/dkundih or https://www.buymeacoffee.com/dkundih in order to keep vandal free is more than welcome.

**A word from the author!**

The library itself, it's maintenance, updates and stability, logo, videos, promotional materials and everything associated with duality are done by **David Kundih** from **Croatia**.

<h1 align='center'> Hi! :wave:</h1>
 
<img src='https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/BLUERED_GHiLI.jpg'/>

<p align='center'>
My name is <b>David Kundih</b> and I am a <b>Master of Engineering in Sustainable Mobility and Logistics</b>, currently specializing in <b>Digital Transformation of Traffic and Logistics using Python, JavaScript, HTML and CSS.</b>
</p>
 
<h4 align='center'>My latest projects:</h4>
<p align='center'>
<a href="https://github.com/dkundih/promet-kc">promet-kc</p>
<p align='center'>
<a href="https://github.com/dkundih/vandal">vandal</p>  
<p align='center'>
<a href="https://github.com/dkundih/duality">duality</p>  
<p align='center'>
<a href="https://github.com/dkundih/logistics">logistics</p>  
<p align='center'>
<a href="https://github.com/dkundih/unin">unin</a></p>
</p>

<h3 align='center'><i>People shine the brightest when they seek to understand what kind of love sustains them.</i></h3>

<p align='center'>
<a href="https://www.instagram.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/instagram.jpg"></a>
<a href="https://www.facebook.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/fb.jpg"></a>
<a href="https://www.linkedin.com/in/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/linkedin.png"></a>
<a href="https://www.pypi.org/user/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/pypi.jpg"></a>
<a href="https://www.buymeacoffee.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/buymeacoffee.jpg"></a>
<a href="https://www.patreon.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/patreon.jpg"></a>
<a href="https://www.behance.net/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/behance.jpg"></a>
<a href="https://www.researchgate.net/profile/David-Kundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/rg.jpg"></a>
